searchData={"items":[{"type":"module","title":"Oban.Met","doc":"Met is a distributed, compacting, multidimensional, telemetry-powered time series datastore for\nOban that requires no configuration. It gathers data for queues, job counts, execution metrics,\nactive crontabs, historic metrics, and more.\n\nMet powers the charts and runtime details shown in the [Oban Web][web] dashboard.\n\n[web]: https://github.com/oban-bg/oban_web","ref":"Oban.Met.html"},{"type":"module","title":"Features - Oban.Met","doc":"- **🤖 Autonomous** - Supervises a collection of autonomous modules that dynamically start and stop alongside\n  Oban instances without any code changes.\n\n- **🎩 Distributed** - Metrics are shared between all connected nodes via pubsub. Leadership is used\n  to restrict expensive operations, such as performing counts, to a single node.\n\n- **📼 Recorded** - Telemetry events and scraped data are stored in-memory as time series data.\n  Values are stored as either gauges or space efficient \"sketches\".\n\n- **🪐 Multidimensional** - Metrics are stored with labels such as `node`, `queue`, `worker`, etc.\n  that can be filtered and grouped dynamically at runtime.\n\n- **🗜️ Compacting** - Time series values are periodically compacted into larger windows of time to\n  save space and optimize querying historic data. Compaction periods use safe defaults, but are\n  configurable.\n\n- **✏️ Estimating** - In supporting systems (Postgres), count queries use optimized estimates\n  automatically for tables with a large number of jobs.\n\n- **🔎 Queryable** - Historic metrics may be filtered and grouped by any label, sliced by\n  arbitrary time intervals, and numeric values aggregated at dynamic percentiles (e.g. P50, P99)\n  without pre-computed histogram buckets.\n\n- **🤝 Handoff** - Ephemeral data storage via data replication with handoff between nodes. All nodes have a\n  shared view of the cluster's data and new nodes are caught up when they come online.","ref":"Oban.Met.html#module-features"},{"type":"module","title":"Installation - Oban.Met","doc":"Oban Met is included with Oban Web and manual installation is only necessary in hybrid\nenvironments (separate Web and Worker nodes).\n\nTo receive metrics from non-web nodes in a system with separate \"web\" and \"worker\" applications\nyou must explicitly include `oban_met` as a dependency for \"workers\".\n\n```elixir\n{:oban_met, \"~> 1.0\"}\n```","ref":"Oban.Met.html#module-installation"},{"type":"module","title":"Usage - Oban.Met","doc":"No configuration is necessary and Oban Met will start automatically in a typical application. A\nvariety of options are provided for more complex or nuanced usage.","ref":"Oban.Met.html#module-usage"},{"type":"module","title":"Auto Start - Oban.Met","doc":"Supervised Met instances start automatically along with Oban instances unless Oban is in testing\nmode. You can disable auto-starting globally with application configuration:\n\n```elixir\nconfig :oban_met, auto_start: false\n```\n\nThen, start instances as a child directly within your Oban app's plugins:\n\n```elixir\nplugins: [\n  Oban.Met,\n  ...\n]\n```","ref":"Oban.Met.html#module-auto-start"},{"type":"module","title":"Customizing Estimates - Oban.Met","doc":"Options for internal `Oban.Met` processes can be overridden from the plugin specification. Most\noptions are internal and not meant to be overridden, but one particularly useful option to tune is\nthe `estimate_limit`. The `estimate_limit` determines at which point state/queue counts switch\nfrom using an accurate `count(*)` call to a much more efficient, but less accurate, estiamte\nfunction.\n\nThe default limit is a conservative 50k, which may be too low for systems with insert spikes. This\ndeclares an override to set the limit to 200k:\n\n```elixir\n{Oban.Met, reporter: [estimate_limit: 200_000]}\n```","ref":"Oban.Met.html#module-customizing-estimates"},{"type":"module","title":"Explicit Migrations - Oban.Met","doc":"Met will create the necessary estimate function automatically when possible. The migration isn't\nnecessary under normal circumstances, but is provided to avoid permission issues or allow full\ncontrol over database changes.\n\n```bash\nmix ecto.gen.migration add_oban_met\n```\n\nOpen the generated migration and delegate the `up/0` and `down/0` functions to\n`Oban.Met.Migration`:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddObanMet do\n  use Ecto.Migration\n\n  def up, do: Oban.Met.Migration.up()\n  def down, do: Oban.Met.Migration.down()\nend\n```\n\nThen, after disabling auto-start, configure the reporter not to auto-migrate if you run the\nexplicit migration:\n\n```elixir\n{Oban.Met, reporter: [auto_migrate: false]}\n```","ref":"Oban.Met.html#module-explicit-migrations"},{"type":"function","title":"Oban.Met.checks/1","doc":"Retrieve stored producer checks.\n\nThis mimics the output of the legacy `Oban.Web.Plugins.Stats.all_gossip/1` function.\n\nChecks are queried approximately every second and broadcast to all connected nodes, so each node\nis a replica of checks from the entire cluster. Checks are stored for 30 seconds before being\npurged.","ref":"Oban.Met.html#checks/1"},{"type":"function","title":"Output - Oban.Met.checks/1","doc":"Checks are the result of `Oban.check_queue/1`, and the exact contents depends on which\n`Oban.Engine` is in use. A `Basic` engine check will look similar to this:\n\n    %{\n      uuid: \"2dde4c0f-53b8-4f59-9a16-a9487454292d\",\n      limit: 10,\n      node: \"me@local\",\n      paused: false,\n      queue: \"default\",\n      running: [100, 102],\n      started_at: ~D[2020-10-07 15:31:00],\n      updated_at: ~D[2020-10-07 15:31:00]\n    }","ref":"Oban.Met.html#checks/1-output"},{"type":"function","title":"Examples - Oban.Met.checks/1","doc":"Get all current checks:\n\n    Oban.Met.checks()\n\nGet current checks for a non-standard Oban isntance:\n\n    Oban.Met.checks(MyOban)","ref":"Oban.Met.html#checks/1-examples"},{"type":"type","title":"Oban.Met.counts/0","doc":"","ref":"Oban.Met.html#t:counts/0"},{"type":"function","title":"Oban.Met.crontab/1","doc":"Get a normalized, unified crontab from all connected nodes.","ref":"Oban.Met.html#crontab/1"},{"type":"function","title":"Examples - Oban.Met.crontab/1","doc":"Get a merged crontab:\n\n    Oban.Met.crontab()\n    [\n      {\"* * * * *\", \"Worker.A\", []},\n      {\"* * * * *\", \"Worker.B\", [[\"args\", %{\"mode\" => \"foo\"}]]}\n    ]\n\nGet the crontab for a non-standard Oban instance:\n\n    Oban.Met.crontab(MyOban)","ref":"Oban.Met.html#crontab/1-examples"},{"type":"type","title":"Oban.Met.filter_value/0","doc":"","ref":"Oban.Met.html#t:filter_value/0"},{"type":"type","title":"Oban.Met.label/0","doc":"","ref":"Oban.Met.html#t:label/0"},{"type":"function","title":"Oban.Met.labels/3","doc":"Get all stored, unique values for a particular label.","ref":"Oban.Met.html#labels/3"},{"type":"function","title":"Examples - Oban.Met.labels/3","doc":"Get all known queues:\n\n    Oban.Met.labels(\"queue\")\n    ~w(alpha gamma delta)\n\nGet all known workers:\n\n    Oban.Met.labels(\"worker\")\n    ~w(MyApp.Worker MyApp.OtherWorker)","ref":"Oban.Met.html#labels/3-examples"},{"type":"function","title":"Oban.Met.latest/3","doc":"Get the latest values for a gauge series, optionally subdivided by a label.\n\nUnlike queues and workers, states are static and constant, so they'll always show up in the\ncounts or subdivision maps.","ref":"Oban.Met.html#latest/3"},{"type":"function","title":"Gauge Series - Oban.Met.latest/3","doc":"Latest counts only apply to `Gauge` series. There are two gauges available (as reported by\n`series/1`:\n\n* `:exec_count` — jobs executing at that moment, including `node`, `queue`, `state`, and\n  `worker` labels.\n\n* `:full_count` — jobs in the database, including `queue`, and `state` labels.","ref":"Oban.Met.html#latest/3-gauge-series"},{"type":"function","title":"Examples - Oban.Met.latest/3","doc":"Get the `:full_count` value without any grouping:\n\n    Oban.Met.latest(:full_count)\n    %{\"all\" => 99}\n\nGroup the `:full_count` value by state:\n\n    Oban.Met.latest(:full_count, group: \"state\")\n    %{\"available\" => 9, \"completed\" => 80, \"executing\" => 5, ...\n\nGroup results by queue:\n\n    Oban.Met.latest(:exec_count, group: \"queue\")\n    %{\"alpha\" => 9, \"gamma\" => 3}\n\nGroup results by node:\n\n    Oban.Met.latest(:exec_count, group: \"node\")\n    %{\"worker.1\" => 6, \"worker.2\" => 5}\n\nFilter values by node:\n\n    Oban.Met.latest(:exec_count, filters: [node: \"worker.1\"])\n    %{\"all\" => 6}\n\nFilter values by queue and state:\n\n    Oban.Met.latest(:exec_count, filters: [node: \"worker.1\", \"worker.2\"])","ref":"Oban.Met.html#latest/3-examples"},{"type":"type","title":"Oban.Met.latest_opts/0","doc":"","ref":"Oban.Met.html#t:latest_opts/0"},{"type":"function","title":"Oban.Met.lookup/2","doc":"Get all stored values for a series without any filtering.","ref":"Oban.Met.html#lookup/2"},{"type":"type","title":"Oban.Met.operation/0","doc":"","ref":"Oban.Met.html#t:operation/0"},{"type":"type","title":"Oban.Met.series/0","doc":"","ref":"Oban.Met.html#t:series/0"},{"type":"function","title":"Oban.Met.series/1","doc":"List all recorded series along with their labels and value type.","ref":"Oban.Met.html#series/1"},{"type":"function","title":"Examples - Oban.Met.series/1","doc":"Oban.Met.series()\n    [\n      %{series: \"exec_time\", labels: [\"state\", \"queue\", \"worker\"], value: Sketch},\n      %{series: \"wait_time\", labels: [\"state\", \"queue\", \"worker\"], value: Sketch},\n      %{series: \"exec_count\", labels: [\"state\", \"queue\", \"worker\"], value: Gauge},\n      %{series: \"full_count\", labels: [\"state\", \"queue\"], value: Gauge}\n    ]","ref":"Oban.Met.html#series/1-examples"},{"type":"type","title":"Oban.Met.series_detail/0","doc":"","ref":"Oban.Met.html#t:series_detail/0"},{"type":"function","title":"Oban.Met.start_link/1","doc":"Start a Met supervisor for an Oban instance.\n\n`Oban.Met` typically starts supervisors automatically when Oban instances initialize. However,\nstarting a supervisor manually can be used if `auto_start` is disabled.","ref":"Oban.Met.html#start_link/1"},{"type":"function","title":"Options - Oban.Met.start_link/1","doc":"These options are required; without them the supervisor won't start:\n\n* `:conf` — configuration for a running Oban instance, required\n\n* `:name` — an optional name for the supervisor, defaults to `Oban.Met`","ref":"Oban.Met.html#start_link/1-options"},{"type":"function","title":"Example - Oban.Met.start_link/1","doc":"Start a supervisor for the default Oban instance:\n\n    Oban.Met.start_link(conf: Oban.config())\n\nStart a supervisor with a custom name:\n\n    Oban.Met.start_link(conf: Oban.config(), name: MyApp.MetSup)","ref":"Oban.Met.html#start_link/1-example"},{"type":"type","title":"Oban.Met.sub_counts/0","doc":"","ref":"Oban.Met.html#t:sub_counts/0"},{"type":"function","title":"Oban.Met.timeslice/3","doc":"Summarize a series of data with an aggregate over a configurable window of time.","ref":"Oban.Met.html#timeslice/3"},{"type":"function","title":"Examples - Oban.Met.timeslice/3","doc":"Retreive a 3 second timeslice of the `exec_time` sketch:\n\n    Oban.Met.timeslice(Oban, :exec_time, lookback: 3)\n    [\n      {2, 16771374649.128689, nil},\n      {1, 24040058779.3428, nil},\n      {0, 22191534459.516357, nil},\n    ]\n\nGroup `exec_time` slices by the `queue` label:\n\n    Oban.Met.timeslice(Oban, :exec_time, group: \"queue\")\n    [\n      {1, 9970235387.031698, \"analysis\"},\n      {0, 11700429279.446463, \"analysis\"},\n      {1, 23097311376.231316, \"default\"},\n      {0, 23097311376.231316, \"default\"},\n      {1, 1520977874.3348415, \"events\"},\n      {0, 2558504265.2738624, \"events\"},\n      ...","ref":"Oban.Met.html#timeslice/3-examples"},{"type":"type","title":"Oban.Met.timeslice_opts/0","doc":"","ref":"Oban.Met.html#t:timeslice_opts/0"},{"type":"type","title":"Oban.Met.ts/0","doc":"","ref":"Oban.Met.html#t:ts/0"},{"type":"type","title":"Oban.Met.value/0","doc":"","ref":"Oban.Met.html#t:value/0"},{"type":"module","title":"Oban.Met.Migration","doc":"Migrations that add estimate functionality.\n\n> #### Migrations Are Not Required {: .tip}\n>\n> Met will create the necessary estimate function automatically when possible. This migration\n> isn't necessary under normal circumstances, but is provided to avoid permission issues or\n> allow full control over database changes.\n>\n> See the section on [Explicit Migrations](installation.html) for more information.","ref":"Oban.Met.Migration.html"},{"type":"module","title":"Usage - Oban.Met.Migration","doc":"To use migrations in your application you'll need to generate an `Ecto.Migration` that wraps\ncalls to `Oban.Met.Migration`:\n\n```bash\nmix ecto.gen.migration add_oban_met\n```\n\nOpen the generated migration and delegate the `up/0` and `down/0` functions to\n`Oban.Met.Migration`:\n\n```elixir\ndefmodule MyApp.Repo.Migrations.AddObanMet do\n  use Ecto.Migration\n\n  def up, do: Oban.Met.Migration.up()\n\n  def down, do: Oban.Met.Migration.down()\nend\n```\n\nThis will run all of the necessary migrations for your database.","ref":"Oban.Met.Migration.html#module-usage"},{"type":"function","title":"Oban.Met.Migration.down/1","doc":"Run the `down` migration.","ref":"Oban.Met.Migration.html#down/1"},{"type":"function","title":"Example - Oban.Met.Migration.down/1","doc":"Run all migrations up to the current version:\n\n    Oban.Met.Migration.down()\n\nRun migrations in an alternate prefix:\n\n    Oban.Met.Migration.down(prefix: \"payments\")","ref":"Oban.Met.Migration.html#down/1-example"},{"type":"function","title":"Oban.Met.Migration.up/1","doc":"Run the `up` migration.","ref":"Oban.Met.Migration.html#up/1"},{"type":"function","title":"Example - Oban.Met.Migration.up/1","doc":"Run all migrations up to the current version:\n\n    Oban.Met.Migration.up()\n\nRun migrations in an alternate prefix:\n\n    Oban.Met.Migration.up(prefix: \"payments\")","ref":"Oban.Met.Migration.html#up/1-example"},{"type":"protocol","title":"Oban.Met.Value","doc":"Tracked data access functions.","ref":"Oban.Met.Value.html"},{"type":"function","title":"Oban.Met.Value.add/2","doc":"Add or append a new value to the data type.","ref":"Oban.Met.Value.html#add/2"},{"type":"function","title":"Oban.Met.Value.merge/2","doc":"Merge two values into one.","ref":"Oban.Met.Value.html#merge/2"},{"type":"function","title":"Oban.Met.Value.quantile/2","doc":"Compute the quantile for a value.","ref":"Oban.Met.Value.html#quantile/2"},{"type":"function","title":"Oban.Met.Value.sum/1","doc":"Sum all data points for a value.","ref":"Oban.Met.Value.html#sum/1"},{"type":"type","title":"Oban.Met.Value.t/0","doc":"All the types that implement this protocol.","ref":"Oban.Met.Value.html#t:t/0"},{"type":"function","title":"Oban.Met.Value.union/2","doc":"Union two values by reducing them into one.","ref":"Oban.Met.Value.html#union/2"},{"type":"module","title":"Oban.Met.Values.Gauge","doc":"One or more non-negative integers captured over time.","ref":"Oban.Met.Values.Gauge.html"},{"type":"function","title":"Oban.Met.Values.Gauge.add/2","doc":"Add to the gauge.","ref":"Oban.Met.Values.Gauge.html#add/2"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.add/2","doc":"iex> 1\n    ...> |> Gauge.new()\n    ...> |> Gauge.add(1)\n    ...> |> Gauge.add(1)\n    ...> |> Map.fetch!(:data)\n    [3]","ref":"Oban.Met.Values.Gauge.html#add/2-examples"},{"type":"function","title":"Oban.Met.Values.Gauge.from_map/1","doc":"Initialize a gauge struct from a stringified map, e.g. encoded JSON.","ref":"Oban.Met.Values.Gauge.html#from_map/1"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.from_map/1","doc":"iex> Gauge.new(2)\n    ...> |> Oban.JSON.encode!()\n    ...> |> Oban.JSON.decode!()\n    ...> |> Gauge.from_map()\n    ...> |> Map.fetch!(:data)\n    [2]","ref":"Oban.Met.Values.Gauge.html#from_map/1-examples"},{"type":"function","title":"Oban.Met.Values.Gauge.merge/2","doc":"Merges two gauges into a one.","ref":"Oban.Met.Values.Gauge.html#merge/2"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.merge/2","doc":"Merging two gauge retains all values:\n\n    iex> gauge_1 = Gauge.new([1, 2])\n    ...> gauge_2 = Gauge.new([2, 3])\n    ...> Gauge.merge(gauge_1, gauge_2).data\n    [1, 2, 2, 3]","ref":"Oban.Met.Values.Gauge.html#merge/2-examples"},{"type":"function","title":"Oban.Met.Values.Gauge.new/1","doc":"Initialize a new gauge.","ref":"Oban.Met.Values.Gauge.html#new/1"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.new/1","doc":"iex> Gauge.new(1).data\n    [1]\n\n    iex> Gauge.new([1, 2]).data\n    [1, 2]","ref":"Oban.Met.Values.Gauge.html#new/1-examples"},{"type":"function","title":"Oban.Met.Values.Gauge.quantile/2","doc":"Compute the quantile for a gauge.","ref":"Oban.Met.Values.Gauge.html#quantile/2"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.quantile/2","doc":"With single values:\n\n    iex> Gauge.quantile(Gauge.new([1, 2, 3]), 1.0)\n    3\n\n    iex> Gauge.quantile(Gauge.new([1, 2, 3]), 0.5)\n    2","ref":"Oban.Met.Values.Gauge.html#quantile/2-examples"},{"type":"function","title":"Oban.Met.Values.Gauge.sum/1","doc":"Compute the sum for a gauge.","ref":"Oban.Met.Values.Gauge.html#sum/1"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.sum/1","doc":"iex> Gauge.sum(Gauge.new(3))\n    3\n\n    iex> Gauge.sum(Gauge.new([1, 2, 3]))\n    6","ref":"Oban.Met.Values.Gauge.html#sum/1-examples"},{"type":"type","title":"Oban.Met.Values.Gauge.t/0","doc":"","ref":"Oban.Met.Values.Gauge.html#t:t/0"},{"type":"function","title":"Oban.Met.Values.Gauge.union/2","doc":"Union two gauges into a single value.","ref":"Oban.Met.Values.Gauge.html#union/2"},{"type":"function","title":"Examples - Oban.Met.Values.Gauge.union/2","doc":"Merging two gauge results in a single value:\n\n    iex> gauge_1 = Gauge.new([1, 2])\n    ...> gauge_2 = Gauge.new([2, 3])\n    ...> Gauge.union(gauge_1, gauge_2).data\n    [8]","ref":"Oban.Met.Values.Gauge.html#union/2-examples"},{"type":"module","title":"Oban.Met.Values.Sketch","doc":"A fast and fully mergeable quantile sketch with relative error guarantees.\n\nDerived from [DogSketch](https://github.com/moosecodebv/dog_sketch), based on DDSketch. This\nvariant has a hard-coded error rate of 0.02 for the sake of simplicity.","ref":"Oban.Met.Values.Sketch.html"},{"type":"function","title":"Oban.Met.Values.Sketch.add/2","doc":"Insert sample values into a sketch.","ref":"Oban.Met.Values.Sketch.html#add/2"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.add/2","doc":"iex> Sketch.new()\n    ...> |> Sketch.add(1)\n    ...> |> Sketch.add(2)\n    ...> |> Sketch.add(3)\n    ...> |> Sketch.size()\n    3","ref":"Oban.Met.Values.Sketch.html#add/2-examples"},{"type":"function","title":"Oban.Met.Values.Sketch.from_map/1","doc":"Initialize a sketch struct from a stringified map, e.g. encoded JSON.","ref":"Oban.Met.Values.Sketch.html#from_map/1"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.from_map/1","doc":"iex> Sketch.new([1, 2])\n    ...> |> Oban.JSON.encode!()\n    ...> |> Oban.JSON.decode!()\n    ...> |> Sketch.from_map()\n    ...> |> Sketch.quantile(1.0)\n    ...> |> floor()\n    2","ref":"Oban.Met.Values.Sketch.html#from_map/1-examples"},{"type":"function","title":"Oban.Met.Values.Sketch.merge/2","doc":"Merge two sketch instances.","ref":"Oban.Met.Values.Sketch.html#merge/2"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.merge/2","doc":"iex> sketch_1 = Sketch.new([1])\n    ...>\n    ...> Sketch.new([2])\n    ...> |> Sketch.merge(sketch_1)\n    ...> |> Sketch.size()\n    2","ref":"Oban.Met.Values.Sketch.html#merge/2-examples"},{"type":"function","title":"Oban.Met.Values.Sketch.new/1","doc":"Create a new sketch instance with an optional error rate.","ref":"Oban.Met.Values.Sketch.html#new/1"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.new/1","doc":"iex> sketch = Sketch.new()\n    ...> Sketch.size(sketch)\n    0\n\n    iex> sketch = Sketch.new(1)\n    ...> Sketch.size(sketch)\n    1\n\n    iex> sketch = Sketch.new([1, 2, 3])\n    ...> Sketch.size(sketch)\n    3","ref":"Oban.Met.Values.Sketch.html#new/1-examples"},{"type":"function","title":"Oban.Met.Values.Sketch.quantile/2","doc":"Compute the quantile value for a sketch.","ref":"Oban.Met.Values.Sketch.html#quantile/2"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.quantile/2","doc":"Without any values:\n\n    iex> Sketch.quantile(Sketch.new(), 0.5)\n    nil\n\nWith recorded values:\n\n    iex> Sketch.new()\n    ...> |> Sketch.add(1)\n    ...> |> Sketch.add(2)\n    ...> |> Sketch.add(3)\n    ...> |> Sketch.quantile(0.5)\n    ...> |> trunc()\n    2","ref":"Oban.Met.Values.Sketch.html#quantile/2-examples"},{"type":"function","title":"Oban.Met.Values.Sketch.sum/1","doc":"Compute the sum for a sketch. Hardcoded to 0.","ref":"Oban.Met.Values.Sketch.html#sum/1"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.sum/1","doc":"iex> Sketch.sum(Sketch.new([1, 2, 3, 3]))\n    0.0","ref":"Oban.Met.Values.Sketch.html#sum/1-examples"},{"type":"type","title":"Oban.Met.Values.Sketch.t/0","doc":"","ref":"Oban.Met.Values.Sketch.html#t:t/0"},{"type":"function","title":"Oban.Met.Values.Sketch.to_list/1","doc":"Convert a sketch into a list of bins and values.","ref":"Oban.Met.Values.Sketch.html#to_list/1"},{"type":"function","title":"Examples - Oban.Met.Values.Sketch.to_list/1","doc":"iex> Sketch.new()\n    ...> |> Sketch.add(1)\n    ...> |> Sketch.add(2)\n    ...> |> Sketch.add(3)\n    ...> |> Sketch.to_list()\n    ...> |> length()\n    3","ref":"Oban.Met.Values.Sketch.html#to_list/1-examples"},{"type":"function","title":"Oban.Met.Values.Sketch.union/2","doc":"Union two sketches into a single value. This is an alias for `merge/2`.","ref":"Oban.Met.Values.Sketch.html#union/2"},{"type":"extras","title":"Changelog","doc":"# Changelog for Oban Met v1.0","ref":"changelog.html"},{"type":"extras","title":"v1.0.3 — 2025-05-06 - Changelog","doc":"- [Examiner] Use parallel execution for health checks.\n\n  Minimize total time taken to scrape checks from producers by parallelizing calls. The worst case\n  time is now O(1) rather than O(n) when producers are busy.","ref":"changelog.html#v1-0-3-2025-05-06"},{"type":"extras","title":"v1.0.2 — 2025-03-14 - Changelog","doc":"This release requires Oban v2.19 because of a dependency on the new JSON module.","ref":"changelog.html#v1-0-2-2025-03-14"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- [Met] Log unexpected messages from trapping servers\n\n  The `reporter` and `cronitor` have a small set of messages they expect. Rather than crashing on\n  unexpected messages, the processes now log a warning instead.\n\n- [Meta] Override application options with passed options\n\n  Passed options weren't relayed to the underlying module and only application level options had\n  any effect. This ensures options from both locations are merged.\n\n- [Met] Use conditional JSON derive and Oban.JSON wrapper","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v1.0.1 — 2025-01-16 - Changelog","doc":"","ref":"changelog.html#v1-0-1-2025-01-16"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- [Value] Implement `JSON.Encoder` for value types\n\n  The encoder is necessary to work with official JSON encoded values as well as legacy Jason.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v1.0.0 — 2025-01-16 - Changelog","doc":"This is the official v1.0 release _and_ the package is now open source!","ref":"changelog.html#v1-0-0-2025-01-16"},{"type":"extras","title":"Enhancements - Changelog","doc":"- [Reporter] Count queries work with all official Oban engines and databases (Postgres, SQLite,\n  and MySQL).\n\n- [Migration] Add ability to explicitly create estimate function through a dedicated migration.\n\n  For databases that don't allow the application connect to create new functions, this adds an\n  `Oban.Met.Migration` module and an option to disable auto-migrating in the reporter.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- [Reporter] Skip queries with empty states or queues to prevent query errors.\n\n  Querying with an empty list may cause the following error:\n\n  ```\n  (Postgrex.Error) ERROR 42809 (wrong_object_type) op ANY/ALL (array)\n  ```\n\n  This fixes the error by skipping queries for empty lists. This could happen if all of the states\n  were above the estimate threshold, or no active queues were found.","ref":"changelog.html#bug-fixes"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.2"}}